##########
ROMCleaner
##########

ROMCleaner will remove files on disk (and from the cache file) that are no longer included in the user config.

ROMCleaner has no config arguments.

API
===

.. autoclass:: romsearch.ROMMover
    :no-index:
    :members:
    :undoc-members: